@@ -151,7 +151,7 @@ class Stock:
 								"(KHTML, like Gecko) Chrome/29.0.1547.62 Safari/537.36'"}
 
 	def _get_soup(self, url):
-		response = get(url, headers=HEADERS, timeout=20)
+		response = get(url, headers=self.HEADERS, timeout=20)
 		assert response.status_code == 200
 		return BeautifulSoup(response.content, 'lxml')
 
@@ -290,7 +290,7 @@ class Stock:
 
 		# Getting news from google news search
 		googlenews = GoogleNews(lang='en', period='14d') # Specify period for news
-		googlenews.self.search(self.ticker) 
+		googlenews.search(self.ticker) 
 		# print([(i, j) for i, j in zip(googlenews.get_texts(), googlenews.get_links())])
 		# To get other pages, do googlenews.get_page(2), etc.
 
